pub(crate) struct BlockRegionRead<'a> {
bounds: BlockRegionBounds,
sections: SmallVec<[Option<RwLockReadGuard<'a, ChunkSection>>; 8]>,
min_chunk_x: i32,
min_chunk_z: i32,
chunk_z_count: usize,
min_section_y: i32,
section_y_count: usize,
world_min_y: i32,
world_max_y: i32,
air: BlockStateId,
void_air: BlockStateId,
}Expand description
Scoped block-state reads over a rectangular set of prelocked sections.
Fields
bounds: BlockRegionBoundssections: SmallVec<[Option<RwLockReadGuard<'a, ChunkSection>>; 8]>min_chunk_x: i32min_chunk_z: i32chunk_z_count: usizemin_section_y: i32section_y_count: usizeworld_min_y: i32world_max_y: i32air: BlockStateIdvoid_air: BlockStateIdImplementations
Sourceimpl BlockRegionRead<'_>
impl BlockRegionRead<'_>
Sourcepub(crate) fn get_block_state(&self, pos: BlockPos) -> Option<BlockStateId>
pub(crate) fn get_block_state(&self, pos: BlockPos) -> Option<BlockStateId>
Returns the block state at pos, or None when it is outside this region.
Positions outside world bounds are void air. Missing Full chunks are air,
matching World::get_block_state.
Sourcepub(crate) fn section(
&self,
section_pos: SectionPos,
) -> Option<BlockSectionRead<'_>>
pub(crate) fn section( &self, section_pos: SectionPos, ) -> Option<BlockSectionRead<'_>>
Returns a prelocked section view, or None for an unloaded or uncached section.