pub(crate) struct BlockSectionRead<'a> {
section_pos: SectionPos,
section: &'a ChunkSection,
}Expand description
A read-only view of one section already locked by a BlockRegionRead.
Fields
section_pos: SectionPossection: &'a ChunkSectionImplementations
Sourceimpl BlockSectionRead<'_>
impl BlockSectionRead<'_>
Sourcepub(crate) fn get_block_state(&self, pos: BlockPos) -> Option<BlockStateId>
pub(crate) fn get_block_state(&self, pos: BlockPos) -> Option<BlockStateId>
Returns a state when pos belongs to this section.